==> huaweicloudsdkelb-3.0.18b0-py3-none-any.whl: huaweicloudsdkelb/v2/model/list_l7policies_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListL7policiesResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'l7policies': 'list[L7policyV2Resp]'
    }

    attribute_map = {
        'l7policies': 'l7policies'
    }

    def __init__(self, l7policies=None):
        """ListL7policiesResponse - a model defined in huaweicloud sdk"""
        
        super().__init__()

        self._l7policies = None
        self.discriminator = None

        if l7policies is not None:
            self.l7policies = l7policies

    @property
    def l7policies(self):
        """Gets the l7policies of this ListL7policiesResponse.

        转发策略对象的列表

        :return: The l7policies of this ListL7policiesResponse.
        :rtype: list[L7policyV2Resp]
        """
        return self._l7policies

    @l7policies.setter
    def l7policies(self, l7policies):
        """Sets the l7policies of this ListL7policiesResponse.

        转发策略对象的列表

        :param l7policies: The l7policies of this ListL7policiesResponse.
        :type: list[L7policyV2Resp]
        """
        self._l7policies = l7policies

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListL7policiesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkelb-3.0.23b0-py3-none-any.whl: huaweicloudsdkelb/v2/model/list_l7policies_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListL7policiesResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'l7policies': 'list[L7policyResp]'
    }

    attribute_map = {
        'l7policies': 'l7policies'
    }

    def __init__(self, l7policies=None):
        """ListL7policiesResponse - a model defined in huaweicloud sdk"""
        
        super().__init__()

        self._l7policies = None
        self.discriminator = None

        if l7policies is not None:
            self.l7policies = l7policies

    @property
    def l7policies(self):
        """Gets the l7policies of this ListL7policiesResponse.

        转发策略对象的列表

        :return: The l7policies of this ListL7policiesResponse.
        :rtype: list[L7policyResp]
        """
        return self._l7policies

    @l7policies.setter
    def l7policies(self, l7policies):
        """Sets the l7policies of this ListL7policiesResponse.

        转发策略对象的列表

        :param l7policies: The l7policies of this ListL7policiesResponse.
        :type: list[L7policyResp]
        """
        self._l7policies = l7policies

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListL7policiesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
